#!/bin/bash

current_theme=""

while true; do
  # Retrieve the current temperature from KWin using dbus-send
  temperature=$(dbus-send --session --dest=org.kde.KWin --type=method_call --print-reply \
    /org/kde/KWin/NightLight org.freedesktop.DBus.Properties.Get string:org.kde.KWin.NightLight string:currentTemperature \
    | grep -oP 'variant\s+uint32\s+\K\d+')

  # Decide the target theme based on the temperature
  if (( temperature == 6500 )); then
    target_theme="org.fedoraproject.fedora.desktop"  # Light theme for == 6500
  elif (( temperature < 6500 )); then
    target_theme="org.kde.breezedark.desktop"  # Dark theme for < 6500
  fi

  # Switch theme only if it's different from the current one
  if [[ "$target_theme" != "$current_theme" ]]; then
    lookandfeeltool -a "$target_theme"
    # Update the current theme to the new one
    current_theme="$target_theme"
    # KDE notification
    notify-send "Theme Switcher" "Switched to $(basename "$target_theme") theme."
  fi

  # Sleep for 15 minutes (900 seconds)
  sleep 900
done
